cosmpy.protos.ibc.applications.transfer.v1 package — cosmpy documentation

# cosmpy.protos.ibc.applications.transfer.v1 package

## Submodules

## cosmpy.protos.ibc.applications.transfer.v1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.applications.transfer.v1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.ibc.applications.transfer.v1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.applications.transfer.v1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.ibc.applications.transfer.v1.query_pb2_grpc.Query

  Bases: `object`

  Query provides defines the gRPC querier service.

  static DenomTrace(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DenomTraces(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.ibc.applications.transfer.v1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query provides defines the gRPC querier service.

  DenomTrace(request, context)

    DenomTrace queries a denomination trace information.

  DenomTraces(request, context)

    DenomTraces queries all denomination traces.

  Params(request, context)

    Params queries all parameters of the ibc-transfer module.

class cosmpy.protos.ibc.applications.transfer.v1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query provides defines the gRPC querier service.

cosmpy.protos.ibc.applications.transfer.v1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.ibc.applications.transfer.v1.transfer_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.applications.transfer.v1.transfer_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.ibc.applications.transfer.v1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.applications.transfer.v1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.ibc.applications.transfer.v1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the ibc/transfer Msg service.

  static Transfer(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.ibc.applications.transfer.v1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the ibc/transfer Msg service.

  Transfer(request, context)

    Transfer defines a rpc handler method for MsgTransfer.

class cosmpy.protos.ibc.applications.transfer.v1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the ibc/transfer Msg service.

cosmpy.protos.ibc.applications.transfer.v1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents